==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/RepositoryImportSpecFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class RepositoryImportSpecFluentImpl<A extends io.fabric8.openshift.api.model.RepositoryImportSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.RepositoryImportSpecFluent<A>{
  public RepositoryImportSpecFluentImpl() {
  }
  public RepositoryImportSpecFluentImpl(io.fabric8.openshift.api.model.RepositoryImportSpec instance) {
    this.withFrom(instance.getFrom()); 
    this.withImportPolicy(instance.getImportPolicy()); 
    this.withIncludeManifest(instance.getIncludeManifest()); 
    this.withReferencePolicy(instance.getReferencePolicy()); 
  }
  private io.fabric8.kubernetes.api.model.ObjectReferenceBuilder from;
  private io.fabric8.openshift.api.model.TagImportPolicyBuilder importPolicy;
  private java.lang.Boolean includeManifest;
  private io.fabric8.openshift.api.model.TagReferencePolicyBuilder referencePolicy;
  
  /**
   * This method has been deprecated, please use method buildFrom instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectReference getFrom() {
    return this.from!=null?this.from.build():null;
  }
  public io.fabric8.kubernetes.api.model.ObjectReference buildFrom() {
    return this.from!=null?this.from.build():null;
  }
  public A withFrom(io.fabric8.kubernetes.api.model.ObjectReference from) {
    _visitables.get("from").remove(this.from);
    if (from!=null){ this.from= new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder(from); _visitables.get("from").add(this.from);} return (A) this;
  }
  public java.lang.Boolean hasFrom() {
    return this.from != null;
  }
  public io.fabric8.openshift.api.model.RepositoryImportSpecFluent.FromNested<A> withNewFrom() {
    return new io.fabric8.openshift.api.model.RepositoryImportSpecFluentImpl.FromNestedImpl();
  }
  public io.fabric8.openshift.api.model.RepositoryImportSpecFluent.FromNested<A> withNewFromLike(io.fabric8.kubernetes.api.model.ObjectReference item) {
    return new io.fabric8.openshift.api.model.RepositoryImportSpecFluentImpl.FromNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.RepositoryImportSpecFluent.FromNested<A> editFrom() {
    return withNewFromLike(getFrom());
  }
  public io.fabric8.openshift.api.model.RepositoryImportSpecFluent.FromNested<A> editOrNewFrom() {
    return withNewFromLike(getFrom() != null ? getFrom(): new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.RepositoryImportSpecFluent.FromNested<A> editOrNewFromLike(io.fabric8.kubernetes.api.model.ObjectReference item) {
    return withNewFromLike(getFrom() != null ? getFrom(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildImportPolicy instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.TagImportPolicy getImportPolicy() {
    return this.importPolicy!=null?this.importPolicy.build():null;
  }
  public io.fabric8.openshift.api.model.TagImportPolicy buildImportPolicy() {
    return this.importPolicy!=null?this.importPolicy.build():null;
  }
  public A withImportPolicy(io.fabric8.openshift.api.model.TagImportPolicy importPolicy) {
    _visitables.get("importPolicy").remove(this.importPolicy);
    if (importPolicy!=null){ this.importPolicy= new io.fabric8.openshift.api.model.TagImportPolicyBuilder(importPolicy); _visitables.get("importPolicy").add(this.importPolicy);} return (A) this;
  }
  public java.lang.Boolean hasImportPolicy() {
    return this.importPolicy != null;
  }
  public A withNewImportPolicy(java.lang.Boolean insecure,java.lang.Boolean scheduled) {
    return (A)withImportPolicy(new TagImportPolicy(insecure, scheduled));
  }
  public io.fabric8.openshift.api.model.RepositoryImportSpecFluent.ImportPolicyNested<A> withNewImportPolicy() {
    return new io.fabric8.openshift.api.model.RepositoryImportSpecFluentImpl.ImportPolicyNestedImpl();
  }
  public io.fabric8.openshift.api.model.RepositoryImportSpecFluent.ImportPolicyNested<A> withNewImportPolicyLike(io.fabric8.openshift.api.model.TagImportPolicy item) {
    return new io.fabric8.openshift.api.model.RepositoryImportSpecFluentImpl.ImportPolicyNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.RepositoryImportSpecFluent.ImportPolicyNested<A> editImportPolicy() {
    return withNewImportPolicyLike(getImportPolicy());
  }
  public io.fabric8.openshift.api.model.RepositoryImportSpecFluent.ImportPolicyNested<A> editOrNewImportPolicy() {
    return withNewImportPolicyLike(getImportPolicy() != null ? getImportPolicy(): new io.fabric8.openshift.api.model.TagImportPolicyBuilder().build());
  }
  public io.fabric8.openshift.api.model.RepositoryImportSpecFluent.ImportPolicyNested<A> editOrNewImportPolicyLike(io.fabric8.openshift.api.model.TagImportPolicy item) {
    return withNewImportPolicyLike(getImportPolicy() != null ? getImportPolicy(): item);
  }
  public java.lang.Boolean getIncludeManifest() {
    return this.includeManifest;
  }
  public A withIncludeManifest(java.lang.Boolean includeManifest) {
    this.includeManifest=includeManifest; return (A) this;
  }
  public java.lang.Boolean hasIncludeManifest() {
    return this.includeManifest != null;
  }
  
  /**
   * This method has been deprecated, please use method buildReferencePolicy instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.TagReferencePolicy getReferencePolicy() {
    return this.referencePolicy!=null?this.referencePolicy.build():null;
  }
  public io.fabric8.openshift.api.model.TagReferencePolicy buildReferencePolicy() {
    return this.referencePolicy!=null?this.referencePolicy.build():null;
  }
  public A withReferencePolicy(io.fabric8.openshift.api.model.TagReferencePolicy referencePolicy) {
    _visitables.get("referencePolicy").remove(this.referencePolicy);
    if (referencePolicy!=null){ this.referencePolicy= new io.fabric8.openshift.api.model.TagReferencePolicyBuilder(referencePolicy); _visitables.get("referencePolicy").add(this.referencePolicy);} return (A) this;
  }
  public java.lang.Boolean hasReferencePolicy() {
    return this.referencePolicy != null;
  }
  public A withNewReferencePolicy(java.lang.String type) {
    return (A)withReferencePolicy(new TagReferencePolicy(type));
  }
  public io.fabric8.openshift.api.model.RepositoryImportSpecFluent.ReferencePolicyNested<A> withNewReferencePolicy() {
    return new io.fabric8.openshift.api.model.RepositoryImportSpecFluentImpl.ReferencePolicyNestedImpl();
  }
  public io.fabric8.openshift.api.model.RepositoryImportSpecFluent.ReferencePolicyNested<A> withNewReferencePolicyLike(io.fabric8.openshift.api.model.TagReferencePolicy item) {
    return new io.fabric8.openshift.api.model.RepositoryImportSpecFluentImpl.ReferencePolicyNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.RepositoryImportSpecFluent.ReferencePolicyNested<A> editReferencePolicy() {
    return withNewReferencePolicyLike(getReferencePolicy());
  }
  public io.fabric8.openshift.api.model.RepositoryImportSpecFluent.ReferencePolicyNested<A> editOrNewReferencePolicy() {
    return withNewReferencePolicyLike(getReferencePolicy() != null ? getReferencePolicy(): new io.fabric8.openshift.api.model.TagReferencePolicyBuilder().build());
  }
  public io.fabric8.openshift.api.model.RepositoryImportSpecFluent.ReferencePolicyNested<A> editOrNewReferencePolicyLike(io.fabric8.openshift.api.model.TagReferencePolicy item) {
    return withNewReferencePolicyLike(getReferencePolicy() != null ? getReferencePolicy(): item);
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RepositoryImportSpecFluentImpl that = (RepositoryImportSpecFluentImpl) o;
    if (from != null ? !from.equals(that.from) :that.from != null) return false;
    if (importPolicy != null ? !importPolicy.equals(that.importPolicy) :that.importPolicy != null) return false;
    if (includeManifest != null ? !includeManifest.equals(that.includeManifest) :that.includeManifest != null) return false;
    if (referencePolicy != null ? !referencePolicy.equals(that.referencePolicy) :that.referencePolicy != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(from,  importPolicy,  includeManifest,  referencePolicy,  super.hashCode());
  }
  public class FromNestedImpl<N> extends io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl<io.fabric8.openshift.api.model.RepositoryImportSpecFluent.FromNested<N>> implements io.fabric8.openshift.api.model.RepositoryImportSpecFluent.FromNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    FromNestedImpl(io.fabric8.kubernetes.api.model.ObjectReference item) {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder(this, item);
    }
    FromNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder(this);
    }
    io.fabric8.kubernetes.api.model.ObjectReferenceBuilder builder;
    public N and() {
      return (N) RepositoryImportSpecFluentImpl.this.withFrom(builder.build());
    }
    public N endFrom() {
      return and();
    }
    
  }
  public class ImportPolicyNestedImpl<N> extends io.fabric8.openshift.api.model.TagImportPolicyFluentImpl<io.fabric8.openshift.api.model.RepositoryImportSpecFluent.ImportPolicyNested<N>> implements io.fabric8.openshift.api.model.RepositoryImportSpecFluent.ImportPolicyNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ImportPolicyNestedImpl(io.fabric8.openshift.api.model.TagImportPolicy item) {
      this.builder = new io.fabric8.openshift.api.model.TagImportPolicyBuilder(this, item);
    }
    ImportPolicyNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.TagImportPolicyBuilder(this);
    }
    io.fabric8.openshift.api.model.TagImportPolicyBuilder builder;
    public N and() {
      return (N) RepositoryImportSpecFluentImpl.this.withImportPolicy(builder.build());
    }
    public N endImportPolicy() {
      return and();
    }
    
  }
  public class ReferencePolicyNestedImpl<N> extends io.fabric8.openshift.api.model.TagReferencePolicyFluentImpl<io.fabric8.openshift.api.model.RepositoryImportSpecFluent.ReferencePolicyNested<N>> implements io.fabric8.openshift.api.model.RepositoryImportSpecFluent.ReferencePolicyNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ReferencePolicyNestedImpl(io.fabric8.openshift.api.model.TagReferencePolicy item) {
      this.builder = new io.fabric8.openshift.api.model.TagReferencePolicyBuilder(this, item);
    }
    ReferencePolicyNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.TagReferencePolicyBuilder(this);
    }
    io.fabric8.openshift.api.model.TagReferencePolicyBuilder builder;
    public N and() {
      return (N) RepositoryImportSpecFluentImpl.this.withReferencePolicy(builder.build());
    }
    public N endReferencePolicy() {
      return and();
    }
    
  }
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/RepositoryImportSpecFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public class RepositoryImportSpecFluentImpl<A extends io.fabric8.openshift.api.model.RepositoryImportSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.RepositoryImportSpecFluent<A>{
  public RepositoryImportSpecFluentImpl() {
  }
  public RepositoryImportSpecFluentImpl(io.fabric8.openshift.api.model.RepositoryImportSpec instance) {
    this.withFrom(instance.getFrom()); 
    this.withImportPolicy(instance.getImportPolicy()); 
    this.withIncludeManifest(instance.getIncludeManifest()); 
    this.withReferencePolicy(instance.getReferencePolicy()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.ObjectReferenceBuilder from;
  private io.fabric8.openshift.api.model.TagImportPolicyBuilder importPolicy;
  private java.lang.Boolean includeManifest;
  private io.fabric8.openshift.api.model.TagReferencePolicyBuilder referencePolicy;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildFrom instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectReference getFrom() {
    return this.from!=null?this.from.build():null;
  }
  public io.fabric8.kubernetes.api.model.ObjectReference buildFrom() {
    return this.from!=null?this.from.build():null;
  }
  public A withFrom(io.fabric8.kubernetes.api.model.ObjectReference from) {
    _visitables.get("from").remove(this.from);
    if (from!=null){ this.from= new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder(from); _visitables.get("from").add(this.from);} return (A) this;
  }
  public java.lang.Boolean hasFrom() {
    return this.from != null;
  }
  public io.fabric8.openshift.api.model.RepositoryImportSpecFluent.FromNested<A> withNewFrom() {
    return new io.fabric8.openshift.api.model.RepositoryImportSpecFluentImpl.FromNestedImpl();
  }
  public io.fabric8.openshift.api.model.RepositoryImportSpecFluent.FromNested<A> withNewFromLike(io.fabric8.kubernetes.api.model.ObjectReference item) {
    return new io.fabric8.openshift.api.model.RepositoryImportSpecFluentImpl.FromNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.RepositoryImportSpecFluent.FromNested<A> editFrom() {
    return withNewFromLike(getFrom());
  }
  public io.fabric8.openshift.api.model.RepositoryImportSpecFluent.FromNested<A> editOrNewFrom() {
    return withNewFromLike(getFrom() != null ? getFrom(): new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.RepositoryImportSpecFluent.FromNested<A> editOrNewFromLike(io.fabric8.kubernetes.api.model.ObjectReference item) {
    return withNewFromLike(getFrom() != null ? getFrom(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildImportPolicy instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.TagImportPolicy getImportPolicy() {
    return this.importPolicy!=null?this.importPolicy.build():null;
  }
  public io.fabric8.openshift.api.model.TagImportPolicy buildImportPolicy() {
    return this.importPolicy!=null?this.importPolicy.build():null;
  }
  public A withImportPolicy(io.fabric8.openshift.api.model.TagImportPolicy importPolicy) {
    _visitables.get("importPolicy").remove(this.importPolicy);
    if (importPolicy!=null){ this.importPolicy= new io.fabric8.openshift.api.model.TagImportPolicyBuilder(importPolicy); _visitables.get("importPolicy").add(this.importPolicy);} return (A) this;
  }
  public java.lang.Boolean hasImportPolicy() {
    return this.importPolicy != null;
  }
  public A withNewImportPolicy(java.lang.Boolean insecure,java.lang.Boolean scheduled) {
    return (A)withImportPolicy(new TagImportPolicy(insecure, scheduled));
  }
  public io.fabric8.openshift.api.model.RepositoryImportSpecFluent.ImportPolicyNested<A> withNewImportPolicy() {
    return new io.fabric8.openshift.api.model.RepositoryImportSpecFluentImpl.ImportPolicyNestedImpl();
  }
  public io.fabric8.openshift.api.model.RepositoryImportSpecFluent.ImportPolicyNested<A> withNewImportPolicyLike(io.fabric8.openshift.api.model.TagImportPolicy item) {
    return new io.fabric8.openshift.api.model.RepositoryImportSpecFluentImpl.ImportPolicyNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.RepositoryImportSpecFluent.ImportPolicyNested<A> editImportPolicy() {
    return withNewImportPolicyLike(getImportPolicy());
  }
  public io.fabric8.openshift.api.model.RepositoryImportSpecFluent.ImportPolicyNested<A> editOrNewImportPolicy() {
    return withNewImportPolicyLike(getImportPolicy() != null ? getImportPolicy(): new io.fabric8.openshift.api.model.TagImportPolicyBuilder().build());
  }
  public io.fabric8.openshift.api.model.RepositoryImportSpecFluent.ImportPolicyNested<A> editOrNewImportPolicyLike(io.fabric8.openshift.api.model.TagImportPolicy item) {
    return withNewImportPolicyLike(getImportPolicy() != null ? getImportPolicy(): item);
  }
  public java.lang.Boolean getIncludeManifest() {
    return this.includeManifest;
  }
  public A withIncludeManifest(java.lang.Boolean includeManifest) {
    this.includeManifest=includeManifest; return (A) this;
  }
  public java.lang.Boolean hasIncludeManifest() {
    return this.includeManifest != null;
  }
  
  /**
   * This method has been deprecated, please use method buildReferencePolicy instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.TagReferencePolicy getReferencePolicy() {
    return this.referencePolicy!=null?this.referencePolicy.build():null;
  }
  public io.fabric8.openshift.api.model.TagReferencePolicy buildReferencePolicy() {
    return this.referencePolicy!=null?this.referencePolicy.build():null;
  }
  public A withReferencePolicy(io.fabric8.openshift.api.model.TagReferencePolicy referencePolicy) {
    _visitables.get("referencePolicy").remove(this.referencePolicy);
    if (referencePolicy!=null){ this.referencePolicy= new io.fabric8.openshift.api.model.TagReferencePolicyBuilder(referencePolicy); _visitables.get("referencePolicy").add(this.referencePolicy);} return (A) this;
  }
  public java.lang.Boolean hasReferencePolicy() {
    return this.referencePolicy != null;
  }
  public A withNewReferencePolicy(java.lang.String type) {
    return (A)withReferencePolicy(new TagReferencePolicy(type));
  }
  public io.fabric8.openshift.api.model.RepositoryImportSpecFluent.ReferencePolicyNested<A> withNewReferencePolicy() {
    return new io.fabric8.openshift.api.model.RepositoryImportSpecFluentImpl.ReferencePolicyNestedImpl();
  }
  public io.fabric8.openshift.api.model.RepositoryImportSpecFluent.ReferencePolicyNested<A> withNewReferencePolicyLike(io.fabric8.openshift.api.model.TagReferencePolicy item) {
    return new io.fabric8.openshift.api.model.RepositoryImportSpecFluentImpl.ReferencePolicyNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.RepositoryImportSpecFluent.ReferencePolicyNested<A> editReferencePolicy() {
    return withNewReferencePolicyLike(getReferencePolicy());
  }
  public io.fabric8.openshift.api.model.RepositoryImportSpecFluent.ReferencePolicyNested<A> editOrNewReferencePolicy() {
    return withNewReferencePolicyLike(getReferencePolicy() != null ? getReferencePolicy(): new io.fabric8.openshift.api.model.TagReferencePolicyBuilder().build());
  }
  public io.fabric8.openshift.api.model.RepositoryImportSpecFluent.ReferencePolicyNested<A> editOrNewReferencePolicyLike(io.fabric8.openshift.api.model.TagReferencePolicy item) {
    return withNewReferencePolicyLike(getReferencePolicy() != null ? getReferencePolicy(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RepositoryImportSpecFluentImpl that = (RepositoryImportSpecFluentImpl) o;
    if (from != null ? !from.equals(that.from) :that.from != null) return false;
    if (importPolicy != null ? !importPolicy.equals(that.importPolicy) :that.importPolicy != null) return false;
    if (includeManifest != null ? !includeManifest.equals(that.includeManifest) :that.includeManifest != null) return false;
    if (referencePolicy != null ? !referencePolicy.equals(that.referencePolicy) :that.referencePolicy != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(from,  importPolicy,  includeManifest,  referencePolicy,  additionalProperties,  super.hashCode());
  }
  public class FromNestedImpl<N> extends io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl<io.fabric8.openshift.api.model.RepositoryImportSpecFluent.FromNested<N>> implements io.fabric8.openshift.api.model.RepositoryImportSpecFluent.FromNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    FromNestedImpl(io.fabric8.kubernetes.api.model.ObjectReference item) {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder(this, item);
    }
    FromNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder(this);
    }
    io.fabric8.kubernetes.api.model.ObjectReferenceBuilder builder;
    public N and() {
      return (N) RepositoryImportSpecFluentImpl.this.withFrom(builder.build());
    }
    public N endFrom() {
      return and();
    }
    
  }
  public class ImportPolicyNestedImpl<N> extends io.fabric8.openshift.api.model.TagImportPolicyFluentImpl<io.fabric8.openshift.api.model.RepositoryImportSpecFluent.ImportPolicyNested<N>> implements io.fabric8.openshift.api.model.RepositoryImportSpecFluent.ImportPolicyNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ImportPolicyNestedImpl(io.fabric8.openshift.api.model.TagImportPolicy item) {
      this.builder = new io.fabric8.openshift.api.model.TagImportPolicyBuilder(this, item);
    }
    ImportPolicyNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.TagImportPolicyBuilder(this);
    }
    io.fabric8.openshift.api.model.TagImportPolicyBuilder builder;
    public N and() {
      return (N) RepositoryImportSpecFluentImpl.this.withImportPolicy(builder.build());
    }
    public N endImportPolicy() {
      return and();
    }
    
  }
  public class ReferencePolicyNestedImpl<N> extends io.fabric8.openshift.api.model.TagReferencePolicyFluentImpl<io.fabric8.openshift.api.model.RepositoryImportSpecFluent.ReferencePolicyNested<N>> implements io.fabric8.openshift.api.model.RepositoryImportSpecFluent.ReferencePolicyNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ReferencePolicyNestedImpl(io.fabric8.openshift.api.model.TagReferencePolicy item) {
      this.builder = new io.fabric8.openshift.api.model.TagReferencePolicyBuilder(this, item);
    }
    ReferencePolicyNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.TagReferencePolicyBuilder(this);
    }
    io.fabric8.openshift.api.model.TagReferencePolicyBuilder builder;
    public N and() {
      return (N) RepositoryImportSpecFluentImpl.this.withReferencePolicy(builder.build());
    }
    public N endReferencePolicy() {
      return and();
    }
    
  }
  
}
